@@ -101,7 +101,7 @@ class ComStandardPagination(PageNumberPagination):
         return make_response(
             total_size=total_size,
             data={},
-            items=[],
+            items=data,
             next_link=next_link,
         )
 
